<template>
  <div class="data-container">
    <!-- <wrapper-title
      :title="'工单数据'"
      :path="'/work-order-center/maintenance/work-order/work-order'"
    ></wrapper-title> -->

    <div class="data-content">
      <div class="data-panel">
        <div class="panel-title" style="margin-bottom: 30px">
          <div class="icon">
            <img src="@/assets/icons/arrow.png" alt="" />
          </div>
          <div class="title">整体工单数</div>
        </div>
        <div class="panel-container">
          <div class="panel-item">
            <data-hola
              :holaTitle="`工单总数`"
              :centerValue="workOrderData.totalNum"
              :holaColor="`#4ea8ff`"
            ></data-hola>
          </div>
          <div class="panel-item">
            <data-hola
              :holaTitle="`已处理工单数`"
              :centerValue="workOrderData.doneNum"
              :holaColor="`#5dec24`"
            ></data-hola>
          </div>
          <div class="panel-item">
            <data-hola
              :holaTitle="`未处理工单数`"
              :centerValue="workOrderData.todoNum"
              :holaColor="`#dfc639`"
            ></data-hola>
          </div>
        </div>
      </div>
      <div class="data-panel">
        <div class="panel-title" style="margin: 50px 0 30px 0">
          <div class="icon">
            <img src="@/assets/icons/arrow.png" alt="" />
          </div>
          <div class="title">分区工单数</div>
        </div>
        <div class="echart-container">
          <div id="barChart" ref="barChart"></div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from "echarts";
import WrapperTitle from "../wrapper-title/index";
import DataHola from "./components/data-hola";
let chart = null;
export default {
  name: "ScreenData",
  components: {
    WrapperTitle,
    DataHola,
  },
  props: {
    workOrderData: {
      type: Object,
      default: {},
    },
    workOrderRegion: {
      type: Array,
      default: null,
    },
  },
  data() {
    return {
      dataList: {
        name: [],
        data1: [],
        data2: [],
      },
    };
  },
  methods: {
    initEchart() {
      const option = {
        grid: {
          top: "10%",
          right: 0,
          bottom: "17%",
        },
        legend: {
          right: 0,
          textStyle: {
            color: "#fff",
          },
        },
        tooltip: {},
        xAxis: {
          type: "category",
          axisLabel: {
            color: "#fff",
            rotate: 45,
          },
          data: this.dataList.name,
        },
        yAxis: {
          axisLabel: {
            color: "#fff",
          },
        },
        series: [
          {
            type: "bar",
            name: "已处理工单数",
            stack: "total",
            itemStyle: {
              color: "#4ea8ff",
            },
            data: this.dataList.data1,
          },
          {
            type: "bar",
            name: "未处理工单数",
            stack: "total",
            itemStyle: {
              color: "#dfc639",
            },
            data: this.dataList.data2,
          },
        ],
      };
      chart.setOption(option, true);
    },
  },
  mounted() {
    chart = echarts.init(this.$refs.barChart);
    this.initEchart();
  },
  watch: {
    workOrderRegion() {
      let name = [];
      let data1 = [];
      let data2 =  [];
      this.workOrderRegion.map((item) => {
        name.push(item.area);
        data1.push(item.todoNum);
        data2.push(item.doneNum);
      })
      this.dataList.name = name;
      this.dataList.data1 = data1;
      this.dataList.data2 = data2;
      chart = echarts.init(this.$refs.barChart);
      this.initEchart();
    }
  },
};
</script>

<style lang="scss" scoped>
.data-container {
  width: 100%;
  height: 500px;
  display: flex;
  flex-direction: column;

  .data-content {
    flex: 1;
    padding: 10px;
  }
}

.echart-container {
  width: 100%;
  height: 260px;

  #barChart {
    width: 100%;
    height: 100%;
  }
}

.panel-title {
  color: #b9b9b9;
  display: flex;
  align-items: center;

  .icon {
    width: 20px;
    margin-right: 5px;

    img {
      width: 100%;
      display: block;
    }
  }
}

.panel-container {
  width: 100%;
  display: flex;
  justify-content: space-around;
  margin: 10px 0;

  .panel-item {
    width: 110px;
    height: 110px;
  }
}
</style>
